@@ -56,9 +56,7 @@ def bind(
             return fun(self)
 
         for key in keys:
-            assert (
-                key not in binding
-            ), f"Key {key} already binded to {binding[key]}"
+            assert key not in binding, f"Key {key} already binded to {binding[key]}"
             binding[key] = fun if repeat_factor else _no_repeat_factor  # type: ignore
 
         return wrapper
@@ -136,9 +134,7 @@ class Controller:
             return self.present_error("No url to open")
         if len(urls) == 1:
             with suspend(self.view) as s:
-                s.call(
-                    config.DEFAULT_OPEN.format(file_path=shlex.quote(urls[0]))
-                )
+                s.call(config.DEFAULT_OPEN.format(file_path=shlex.quote(urls[0])))
             return
         with suspend(self.view) as s:
             s.run_with_input(config.URL_VIEW, "\n".join(urls))
@@ -297,14 +293,13 @@ class Controller:
             return
         reply_to_msg = self.model.current_msg_id
         msg = MsgProxy(self.model.current_msg)
-        with NamedTemporaryFile("w+", suffix=".txt") as f, suspend(
-            self.view
-        ) as s:
+        with NamedTemporaryFile("w+", suffix=".txt") as f, suspend(self.view) as s:
             f.write(insert_replied_msg(msg))
             f.seek(0)
             s.call(config.LONG_MSG_CMD.format(file_path=shlex.quote(f.name)))
-            with open(f.name) as f:
-                if replied_msg := strip_replied_msg(f.read().strip()):
+            # Use a different variable name to avoid overwriting the NamedTemporaryFile
+            with open(f.name) as input_file:
+                if replied_msg := strip_replied_msg(input_file.read().strip()):
                     self.model.view_all_msgs()
                     self.tg.reply_message(chat_id, reply_to_msg, replied_msg)
                     self.present_info("Message sent")
@@ -331,19 +326,15 @@ class Controller:
         if not self.can_send_msg() or chat_id is None:
             self.present_info("Can't send msg in this chat")
             return
-        with NamedTemporaryFile("r+", suffix=".txt") as f, suspend(
-            self.view
-        ) as s:
+        with NamedTemporaryFile("r+", suffix=".txt") as f, suspend(self.view) as s:
             self.tg.send_chat_action(chat_id, ChatAction.chatActionTyping)
             s.call(config.LONG_MSG_CMD.format(file_path=shlex.quote(f.name)))
-            with open(f.name) as f:
-                if msg := f.read().strip():
+            with open(f.name) as input_file:
+                if msg := input_file.read().strip():
                     self.model.send_message(text=msg)
                     self.present_info("Message sent")
                 else:
-                    self.tg.send_chat_action(
-                        chat_id, ChatAction.chatActionCancel
-                    )
+                    self.tg.send_chat_action(chat_id, ChatAction.chatActionCancel)
                     self.present_info("Message wasn't sent")
 
     @bind(msg_handler, ["dd"])
@@ -364,8 +355,8 @@ class Controller:
         try:
             with NamedTemporaryFile("w") as f, suspend(self.view) as s:
                 s.call(config.FILE_PICKER_CMD.format(file_path=f.name))
-                with open(f.name) as f:
-                    file_path = f.read().strip()
+                with open(f.name) as input_file:
+                    file_path = input_file.read().strip()
         except FileNotFoundError:
             pass
         if not file_path or not os.path.isfile(file_path):
@@ -378,9 +369,7 @@ class Controller:
         }
         mime = get_mime(file_path)
         if mime in ("image", "video", "animation"):
-            resp = self.view.status.get_input(
-                f"Upload <{file_path}> compressed?[Y/n]"
-            )
+            resp = self.view.status.get_input(f"Upload <{file_path}> compressed?[Y/n]")
             self.render_status()
             if resp is None:
                 return self.present_info("Uploading cancelled")
@@ -445,11 +434,7 @@ class Controller:
     def record_voice(self) -> None:
         file_path = f"/tmp/voice-{datetime.now()}.oga"
         with suspend(self.view) as s:
-            s.call(
-                config.VOICE_RECORD_CMD.format(
-                    file_path=shlex.quote(file_path)
-                )
-            )
+            s.call(config.VOICE_RECORD_CMD.format(file_path=shlex.quote(file_path)))
         resp = self.view.status.get_input(
             f"Do you want to send recording: {file_path}? [Y/n]"
         )
@@ -486,9 +471,9 @@ class Controller:
 
     def can_send_msg(self) -> bool:
         chat = self.model.chats.chats[self.model.current_chat]
-        return chat["permissions"]["can_send_messages"]
+        return chat["permissions"]["can_send_basic_messages"]
 
-    def _open_msg(self, msg: MsgProxy, cmd: str = None) -> None:
+    def _open_msg(self, msg: MsgProxy, cmd: Optional[str] = None) -> None:
         if msg.is_text:
             with NamedTemporaryFile("w", suffix=".txt") as f:
                 f.write(msg.text_content)
@@ -538,14 +523,12 @@ class Controller:
         if not msg.can_be_edited:
             return self.present_error("Meessage can't be edited!")
 
-        with NamedTemporaryFile("r+", suffix=".txt") as f, suspend(
-            self.view
-        ) as s:
+        with NamedTemporaryFile("r+", suffix=".txt") as f, suspend(self.view) as s:
             f.write(msg.text_content)
             f.flush()
             s.call(f"{config.EDITOR} {f.name}")
-            with open(f.name) as f:
-                if text := f.read().strip():
+            with open(f.name) as input_file:
+                if text := input_file.read().strip():
                     self.model.edit_message(text=text)
                     self.present_info("Message edited")
 
@@ -638,17 +621,13 @@ class Controller:
     @bind(chat_handler, ["n"])
     def next_found_chat(self) -> None:
         """Go to next found chat"""
-        if self.model.set_current_chat_by_id(
-            self.model.chats.next_found_chat()
-        ):
+        if self.model.set_current_chat_by_id(self.model.chats.next_found_chat()):
             self.render()
 
     @bind(chat_handler, ["N"])
     def prev_found_chat(self) -> None:
         """Go to previous found chat"""
-        if self.model.set_current_chat_by_id(
-            self.model.chats.next_found_chat(True)
-        ):
+        if self.model.set_current_chat_by_id(self.model.chats.next_found_chat(True)):
             self.render()
 
     @bind(chat_handler, ["/"])
@@ -659,7 +638,9 @@ class Controller:
             return self.present_info("Search discarded")
 
         rv = self.tg.search_contacts(msg)
-        chat_ids = rv.update["chat_ids"]
+        if rv.error:
+            return self.present_info("Search error")
+        chat_ids = rv.update.get("chat_ids", [])
         if not chat_ids:
             return self.present_info("Chat not found")
 
@@ -854,9 +835,7 @@ class Controller:
             msgs_left_scroll_threshold=MSGS_LEFT_SCROLL_THRESHOLD,
         )
         chat = self.model.chats.chats[self.model.current_chat]
-        self.view.msgs.draw(
-            current_msg_idx, msgs, MSGS_LEFT_SCROLL_THRESHOLD, chat
-        )
+        self.view.msgs.draw(current_msg_idx, msgs, MSGS_LEFT_SCROLL_THRESHOLD, chat)
 
     def notify_for_message(self, chat_id: int, msg: MsgProxy) -> None:
         # do not notify, if muted
@@ -907,9 +886,5 @@ def insert_replied_msg(msg: MsgProxy) -> str:
 
 def strip_replied_msg(msg: str) -> str:
     return "\n".join(
-        [
-            line
-            for line in msg.split("\n")
-            if not line.startswith(REPLY_MSG_PREFIX)
-        ]
+        [line for line in msg.split("\n") if not line.startswith(REPLY_MSG_PREFIX)]
     )
