@@ -86,11 +86,7 @@ class Model:
 
     def set_current_chat_by_id(self, chat_id: int) -> bool:
         idx = next(
-            iter(
-                i
-                for i, chat in enumerate(self.chats.chats)
-                if chat["id"] == chat_id
-            )
+            iter(i for i, chat in enumerate(self.chats.chats) if chat["id"] == chat_id)
         )
         return self.set_current_chat(idx)
 
@@ -128,8 +124,10 @@ class Model:
     def view_all_msgs(self) -> None:
         chat = self.chats.chats[self.current_chat]
         chat_id = chat["id"]
-        msg_id = chat["last_message"]["id"]
-        self.tg.view_messages(chat_id, [msg_id])
+        # Handle case where chat might not have last_message
+        if "last_message" in chat and chat["last_message"] is not None:
+            msg_id = chat["last_message"]["id"]
+            self.tg.view_messages(chat_id, [msg_id])
 
     def next_msg(self, step: int = 1) -> bool:
         chat_id = self.chats.id_by_index(self.current_chat)
@@ -238,9 +236,7 @@ class Model:
         copy_to_clipboard("\n".join(buffer))
         return True
 
-    def copy_files(
-        self, chat_id: int, msg_ids: List[int], dest_dir: str
-    ) -> bool:
+    def copy_files(self, chat_id: int, msg_ids: List[int], dest_dir: str) -> bool:
         is_copied = False
         for msg_id in msg_ids:
             _msg = self.msgs.get_message(chat_id, msg_id)
@@ -269,10 +265,10 @@ class Model:
         group_id = chat["type"]["basic_group_id"]
         result = self.tg.get_basic_group_full_info(group_id)
         result.wait()
-        chat_info = result.update
+        chat_info = result.update if not result.error else {}
         basic_info = self.tg.get_basic_group(group_id)
         basic_info.wait()
-        basic_info = basic_info.update
+        basic_info = basic_info.update if not basic_info.error else {}
         return {
             chat["title"]: f"{basic_info['member_count']} members",
             "Info": chat_info["description"],
@@ -280,11 +276,9 @@ class Model:
         }
 
     def get_supergroup_info(self, chat: Dict[str, Any]) -> Dict[str, Any]:
-        result = self.tg.get_supergroup_full_info(
-            chat["type"]["supergroup_id"]
-        )
+        result = self.tg.get_supergroup_full_info(chat["type"]["supergroup_id"])
         result.wait()
-        chat_info = result.update
+        chat_info = result.update if not result.error else {}
         return {
             chat["title"]: f"{chat_info['member_count']} members",
             "Info": chat_info["description"],
@@ -292,11 +286,9 @@ class Model:
         }
 
     def get_channel_info(self, chat: Dict[str, Any]) -> Dict[str, Any]:
-        result = self.tg.get_supergroup_full_info(
-            chat["type"]["supergroup_id"]
-        )
+        result = self.tg.get_supergroup_full_info(chat["type"]["supergroup_id"])
         result.wait()
-        chat_info = result.update
+        chat_info = result.update if not result.error else {}
         return {
             chat["title"]: "subscribers",
             "Info": chat_info["description"],
@@ -306,11 +298,9 @@ class Model:
     def get_secret_chat_info(self, chat: Dict[str, Any]) -> Dict[str, Any]:
         result = self.tg.get_secret_chat(chat["type"]["secret_chat_id"])
         result.wait()
-        chat_info = result.update
-        enc_key = base64.b64decode(chat_info["key_hash"])[:32].hex()
-        hex_key = " ".join(
-            [enc_key[i : i + 2] for i in range(0, len(enc_key), 2)]
-        )
+        chat_info = result.update if not result.error else {}
+        enc_key = base64.b64decode(chat_info.get("key_hash", ""))[:32].hex()
+        hex_key = " ".join([enc_key[i : i + 2] for i in range(0, len(enc_key), 2)])
 
         state = "Unknown"
         try:
@@ -386,9 +376,7 @@ class ChatModel:
             return None
         return self.chats[index]["id"]
 
-    def fetch_chats(
-        self, offset: int = 0, limit: int = 10
-    ) -> List[Dict[str, Any]]:
+    def fetch_chats(self, offset: int = 0, limit: int = 10) -> List[Dict[str, Any]]:
         if offset + limit > len(self.chats):
             self._load_next_chats()
 
@@ -401,7 +389,7 @@ class ChatModel:
         """
         if self.have_full_chat_list:
             return None
-        offset_order = 2 ** 63 - 1
+        offset_order = 2**63 - 1
         offset_chat_id = 0
         if len(self.chats):
             offset_chat_id = self.chats[-1]["id"]
@@ -431,7 +419,7 @@ class ChatModel:
         if result.error:
             log.error(f"get chat error: {result.error_info}")
             return {}
-        return result.update
+        return result.update if not result.error else {}
 
     def add_chat(self, chat: Dict[str, Any]) -> None:
         chat_id = chat["id"]
@@ -467,9 +455,7 @@ class ChatModel:
             if int(chat["order"]) == 0:
                 self.inactive_chats[chat_id] = chat
                 self.chat_ids.discard(chat_id)
-                self.chats = [
-                    _chat for _chat in self.chats if _chat["id"] != chat_id
-                ]
+                self.chats = [_chat for _chat in self.chats if _chat["id"] != chat_id]
                 log.info(f"Removing chat '{chat['title']}'")
             else:
                 self._sort_chats()
@@ -566,9 +552,7 @@ class MsgModel:
         # that is the last case to implement
         # https://core.telegram.org/tdlib/docs/classtd_1_1td__api_1_1update_message_content_opened.html
 
-    def update_msg(
-        self, chat_id: int, msg_id: int, **fields: Dict[str, Any]
-    ) -> None:
+    def update_msg(self, chat_id: int, msg_id: int, **fields: Dict[str, Any]) -> None:
         msg = self.msgs[chat_id].get(msg_id)
         if not msg:
             return
@@ -590,7 +574,7 @@ class MsgModel:
                 limit=len(self.msg_ids[chat_id]) + limit,
             )
         result.wait()
-        if not result or not result.update["messages"]:
+        if result.error or not result.update.get("messages"):
             return []
 
         messages = result.update["messages"]
@@ -607,7 +591,8 @@ class MsgModel:
                 limit=len(self.msg_ids[chat_id]) + limit,
             )
             result.wait()
-            messages += result.update["messages"]
+            if not result.error and "messages" in result.update:
+                messages += result.update["messages"]
 
         return messages
 
@@ -615,17 +600,13 @@ class MsgModel:
         self, chat_id: int, offset: int = 0, limit: int = 10
     ) -> List[Tuple[int, Dict[str, Any]]]:
         if offset + limit > len(self.msg_ids[chat_id]):
-            msgs = self._fetch_msgs_until_limit(
-                chat_id, offset, offset + limit
-            )
+            msgs = self._fetch_msgs_until_limit(chat_id, offset, offset + limit)
             for msg in msgs:
                 self.add_message(chat_id, msg)
 
         return [
             (i, self.msgs[chat_id][msg_id])
-            for i, msg_id in enumerate(
-                self.msg_ids[chat_id][offset : offset + limit]
-            )
+            for i, msg_id in enumerate(self.msg_ids[chat_id][offset : offset + limit])
         ]
 
     def edit_message(self, chat_id: int, message_id: int, text: str) -> bool:
@@ -653,7 +634,6 @@ User = namedtuple("User", ["id", "name", "status", "order"])
 
 
 class UserModel:
-
     types = {
         "userTypeUnknown": "unknown",
         "userTypeBot": "bot",
@@ -679,12 +659,10 @@ class UserModel:
         if result.error:
             log.error(f"get myself error: {result.error_info}")
             return {}
-        self.me = result.update
+        self.me = result.update if not result.error else {}
         return self.me
 
-    def get_user_action(
-        self, chat_id: int
-    ) -> Tuple[Optional[int], Optional[str]]:
+    def get_user_action(self, chat_id: int) -> Tuple[Optional[int], Optional[str]]:
         action = self.actions.get(chat_id)
         if action is None:
             return None, None
@@ -778,8 +756,8 @@ class UserModel:
         if result.error:
             log.warning(f"get user full info error: {result.error_info}")
             return {}
-        user["full_info"] = result.update
-        return result.update
+        user["full_info"] = result.update if not result.error else {}
+        return result.update if not result.error else {}
 
     def get_user(self, user_id: int) -> Dict[str, Any]:
         if user_id in self.not_found:
@@ -792,8 +770,8 @@ class UserModel:
             log.warning(f"get user error: {result.error_info}")
             self.not_found.add(user_id)
             return {}
-        self.users[user_id] = result.update
-        return result.update
+        self.users[user_id] = result.update if not result.error else {}
+        return result.update if not result.error else {}
 
     def get_group_info(self, group_id: int) -> Optional[Dict[str, Any]]:
         if group_id in self.groups:
@@ -801,9 +779,7 @@ class UserModel:
         self.tg.get_basic_group(group_id)
         return None
 
-    def get_supergroup_info(
-        self, supergroup_id: int
-    ) -> Optional[Dict[str, Any]]:
+    def get_supergroup_info(self, supergroup_id: int) -> Optional[Dict[str, Any]]:
         if supergroup_id in self.supergroups:
             return self.supergroups[supergroup_id]
         self.tg.get_supergroup(supergroup_id)
@@ -819,7 +795,7 @@ class UserModel:
         if result.error:
             log.error("get contacts error: %s", result.error_info)
             return None
-        self.contacts = result.update
+        self.contacts = result.update if not result.error else {}
         return self.contacts
 
     def get_user_label(self, user_id: int) -> str:
@@ -827,10 +803,10 @@ class UserModel:
             return ""
         user = self.get_user(user_id)
         if user.get("first_name") and user.get("last_name"):
-            return f'{user["first_name"]} {user["last_name"]}'[:20]
+            return f"{user['first_name']} {user['last_name']}"[:20]
 
         if user.get("first_name"):
-            return f'{user["first_name"]}'[:20]
+            return f"{user['first_name']}"[:20]
 
         if user.get("username"):
             return "@" + user["username"]
